<?php

/**
 * PostExchange
 * Functions related to Questions, Answers, and Comments
 *
 * @package stackPHP
 * @author George Edison <admin@quickmediasolutions.com>, Marco Ceppi <marco.ceppi.use@gmail.com>
 */

require_once "StackBase.php"

class PostExchange extends StackBase
{
	public function __construct( $site = NULL, $key = NULL )
	{
		// Initialize the parent class with
		// the API key and site
		parent::__construct( $site, $key );
	}

	/**
	 * Answer
	 * Retireve an answer associated with the answer_id
	 * 
	 * @param int $answer_id
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of answer data
	 */
	public function Answer( $answer_id, $params = array() )
	{
		return $this->_fetchPage('answers/' . $answer_id, $params);
	}

	/**
	 * Answer's Comments
	 * Retrieve a list of all comments associated with one answer
	 * 
	 * @param int $answer_id
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of comments
	 */
	public function AnswersComments( $answer_id, $params = array() )
	{
		return $this->_fetchPage('answers/' . $answer_id . '/comments', $params);
	}

	/**
	 * Comment
	 * Retrieve a comment and all associated data
	 * 
	 * @param int $comment_id
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of comment data
	 */
	public function Comment( $comment_id, $params = array() )
	{
		return $this->_fetchPage('comments/' . $comment_id, $params);
	}

	/**
	 * Posts Comments
	 * Retrieve a comment and all associated data
	 * 
	 * @param int $comment_id
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of comment data
	 */
	public function PostsComments( $post_id, $params = array() )
	{
		return $this->_fetchPage('posts/' . $post_id . '/comments', $params);
	}

	/**
	 * Questions
	 * Retrieve a list of Questions
	 * 
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of questions
	 */
	public function Questions( $params = array()) 
	{
		return $this->_fetchPage('questions', $params);
	}

	/**
	 * Question
	 * Retrieve a question and all associated data
	 * 
	 * @param int $question_id
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of question data
	 */
	public function Question( $question_id, $params = array() )
	{
		return $this->_fetchPage('questions/' . $question_id, $params);
	}

	/**
	 * Question's Answers
	 * Retrieve a list of answers for a question
	 * 
	 * @param int $question_id
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of answer data
	 */
	public function QuestionsAnswers( $question_id, $params = array() )
	{
		return $this->_fetchPage('questions/' . $question_id . '/answers', $params);
	}

	/**
	 * Question's Comments
	 * Retrieve a list of comments for a question
	 * 
	 * @param int $question_id
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of comment data
	 */
	public function QuestionsComments( $question_id, $params = array() )
	{
		return $this->_fetchPage('questions/' . $question_id . '/comments', $params);
	}

	/**
	 * Question's Timeline
	 * Retrieve comprehensive data regarding a question
	 * 
	 * @param int $question_id
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of timline data
	 */
	public function QuestionsTimeline( $question_id, $params = array() )
	{
		return $this->_fetchPage('questions/' . $question_id . '/timeline', $params);
	}

	/**
	 * Unanswered Questions
	 * Retrieve a list of unanswered questions
	 * 
	 * @param array $params Parameters for the API
	 * 
	 * @return false|array of questions
	 */
	public function Unanswered( $params = array() )
	{
		return $this->_fetchPage('questions/unanswered', $params);
	}

	/**
	 * Search
	 * Search for posts based on criteria
	 * 
	 * @param array $params One of these must be either: intitle, tagged, nottagged
	 * 
	 * @return false|array of results
	 */
	public function Search( $params = array() )
	{
		return $this->_fetchPage('search', $params);
	}

	/**
	 * Tags
	 * Interface for accessing tag data
	 * 
	 * @param array $params 
	 * 
	 * @return false|array of tags
	 */
	public function Tags($params=array())
	{
		return $this->_fetchPage('tags',$params);
	}

	public function RevisionsByIdMethod($id,$params=array())
	{
		return $this->_fetchPage('revisions/' . $id,$params);
	}

	public function RevisionsByIdGUIDMethod($id,$GUID,$params=array())
	{
		return $this->_fetchPage('revisions/' . $id . '/' . $GUID,$params);
	}
}
